@@ -37,6 +37,7 @@ coxUI <- function(id) {
 #' @param nfactor.limit nlevels limit in factor variable, Default: 10
 #' @param design.survey reactive survey data. default: NULL
 #' @param default.unires Set default independent variables using univariate analysis.
+#' @param limit.unires Change to default.unires = F if number of independent variables > limit.unires, Default: 20
 #' @param id.cluster reactive cluster variable if marginal cox model, Default: NULL
 #' @return Shiny modulde server for Cox's model.
 #' @details Shiny modulde server for Cox's model.
@@ -76,7 +77,7 @@ coxUI <- function(id) {
 #' @importFrom purrr map_lgl
 #' @importFrom survival cluster coxph Surv
 
-coxModule <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, default.unires = T, id.cluster = NULL) {
+coxModule <- function(input, output, session, data, data_label, data_varStruct = NULL, nfactor.limit = 10, design.survey = NULL, default.unires = T, limit.unires = 20, id.cluster = NULL) {
 
   ## To remove NOTE.
   level <- val_label <- variable <- NULL
@@ -185,10 +186,11 @@ coxModule <- function(input, output, session, data, data_label, data_varStruct =
                             } else{
                               forms <- as.formula(paste("survival::Surv(", input$time_cox, ",", input$event_cox, ") ~ ", v, " + cluster(", id.cluster(), ")", sep = ""))
                             }
-                            coef <- summary(survival::coxph(forms, data = data.cox))$coefficients
-                            sigOK <- !all(coef[, "Pr(>|z|)"] > 0.05)
+                            coef <- tryCatch(summary(survival::coxph(forms, data = data.cox))$coefficients, error = function(e){return(NULL)})
+                            sigOK <- ifelse(is.null(coef), F, !all(coef[, "Pr(>|z|)"] > 0.05))
                             return(sigOK)
                           })
+        if (length(varsIni[varsIni == T]) > limit.unires) {varsIni <- c(T, rep(F, length(indep.cox) -1))}
       } else{
         varsIni <- c(T, rep(F, length(indep.cox) -1))
       }
@@ -201,10 +203,11 @@ coxModule <- function(input, output, session, data, data_label, data_varStruct =
         varsIni <- sapply(indep.cox,
                           function(v){
                             forms <- as.formula(paste("survival::Surv(",input$time_cox,",", input$event_cox,") ~ ", v, sep=""))
-                            coef <- summary(survey::svycoxph(forms, design =data.design))$coefficients
-                            sigOK <- !all(coef[, "Pr(>|z|)"] > 0.05)
+                            coef <- tryCatch(summary(survey::svycoxph(forms, design =data.design))$coefficients, error = function(e){return(NULL)})
+                            sigOK <- ifelse(is.null(coef), F, !all(coef[, "Pr(>|z|)"] > 0.05))
                             return(sigOK)
                           })
+        if (length(varsIni[varsIni == T]) > limit.unires) {varsIni <- c(T, rep(F, length(indep.cox) -1))}
       } else{
         varsIni <- c(T, rep(F, length(indep.cox) -1))
       }
